# ML Training

Scripts for training and fine-tuning ML models.

## Structure

- `dataset/` - Dataset preparation tools
- `output/` - Training outputs (checkpoints, logs)
- `*.py` - Training scripts

For OCR documentation, see the OCR module documentation.
